<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>notification::BubbleItem</name>
    <message>
        <source>just now</source>
        <translation>gerade eben</translation>
    </message>
    <message>
        <source>1 new message</source>
        <translation>1 neue Nachricht</translation>
    </message>
</context>
<context>
    <name>notification::BubbleModel</name>
    <message>
        <source>%1 minutes ago</source>
        <translation>vor %1 Minuten</translation>
    </message>
</context>
</TS>